@@ -4,6 +4,40 @@ import sys
 
 from ._request_handler import retry_session, general_call
 
+class authentication():
+
+    from warnings import warn
+    msg = 'authentication() is deprecated and it will be removed in alchemyml \
+        0.1.30; use method get_api_token directly from class alchemyml instead'
+    warn(msg, DeprecationWarning)
+    
+    def get_api_token(self, username, password):
+        '''
+        This method returns the necessary token to be used from now on for the 
+        API requests. To be able to make use of the API before all it is 
+        necessary to sign-up.
+
+        Parameters:
+
+        username (str): Username. 
+        password (str): Password. 
+        '''
+        from ._request_handler import retry_session
+
+        url = 'https://alchemyml.com/api/token/'
+        data = json.dumps({'username':username, 'password':password})
+        session = retry_session(retries = 10)
+        r = session.post(url, data)
+
+        if r.status_code == 200:
+            tokenJSON = json.loads(r.text)
+            return tokenJSON['access']
+
+        else:
+            msgJSON = json.loads(r.text)
+            msg = msgJSON['message']
+            return msg
+
 class dataset():
     '''
     Class to manage operations on datasets: uploading, updating, getting a 
